# amoni
A command line utility for local development of Anvil apps.

## Why the name?
It's [Greek for anvil](https://translate.google.com/?sl=auto&tl=el&text=anvil&op=translate) and the idea for this library was conceived on a sunny veranda on the island of Κέρκυρα (Corfu).
